@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-help.c,v 1.2 2005/12/12 17:27:55 pborelli Exp $
+ * $Id: gedit-commands-help.c,v 1.2.2.1 2006/04/10 09:37:25 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -72,22 +72,17 @@ gedit_cmd_help_about (GtkAction   *action,
 	static const gchar copyright[] = \
 		"Copyright \xc2\xa9 1998-2000 Evan Lawrence, Alex Robert\n"
 		"Copyright \xc2\xa9 2000-2002 Chema Celorio, Paolo Maggi\n"
-		"Copyright \xc2\xa9 2003-2005 Paolo Maggi";
+		"Copyright \xc2\xa9 2003-2006 Paolo Maggi";
 
 	static const gchar comments[] = \
 		N_("gedit is a small and lightweight text editor for the "
 		   "GNOME Desktop");
 
-	static GdkPixbuf *logo = NULL;
+	GdkPixbuf *logo;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	if(!logo)
-	{
-		logo = gdk_pixbuf_new_from_file (
-			GNOME_ICONDIR "/gedit-logo.png",
-			NULL);
-	}
+	logo = gdk_pixbuf_new_from_file (GNOME_ICONDIR "/gedit-logo.png", NULL);
 
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "authors", authors,
@@ -98,6 +93,9 @@ gedit_cmd_help_about (GtkAction   *action,
 			       "translator-credits", _("translator-credits"),
 			       "version", VERSION,
 			       "website", "http://www.gedit.org",
-			       "name", _("gedit"),
+			       "name", "gedit",
 			       NULL);
+
+	if (logo)
+		g_object_unref (logo);
 }
