@@ -28,7 +28,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-session.c,v 1.11 2006/02/12 11:57:51 pborelli Exp $
+ * $Id: gedit-session.c,v 1.12.2.1 2006/05/29 18:17:33 pborelli Exp $
  */
 
 
@@ -369,7 +369,7 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 					    gint                          response_id,
 					    GeditWindow                  *window)
 {
-	const GList *selected_documents;
+	GList *selected_documents;
 	GSList *l;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -391,11 +391,11 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 
 			g_object_set_data (G_OBJECT (window),
 					   GEDIT_SESSION_LIST_OF_DOCS_TO_SAVE,
-					   g_list_copy (selected_documents));
+					   selected_documents);
 
 			_gedit_cmd_file_save_documents_list (window, selected_documents);
 
-			// FIXME: also need to lock the window to prevent further changes..
+			/* FIXME: also need to lock the window to prevent further changes... */
 
 			break;
 
@@ -605,9 +605,6 @@ client_die_cb (GnomeClient *client, gpointer data)
 
 	gedit_debug_message (DEBUG_FILE, "Unref gedit_app_server: DONE");
 #endif
-	gedit_prefs_manager_app_shutdown ();
-	gedit_metadata_manager_shutdown ();
-	gedit_plugins_engine_shutdown ();
 
 	gtk_main_quit ();
 }
