@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c,v 1.19 2006/02/25 01:07:10 pborelli Exp $
+ * $Id: gedit-window.c,v 1.20.2.1 2006/04/20 16:53:41 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -850,7 +850,7 @@ recent_tooltip_func_gtk (GtkTooltips   *tooltips,
 	gchar *uri_for_display;
 	gchar *trunc_uri;
 
-	uri_for_display = egg_recent_item_get_uri_for_display (item);
+	uri_for_display = gedit_utils_format_uri_for_display (egg_recent_item_peek_uri (item));
 	g_return_if_fail (uri_for_display != NULL);
 
 	trunc_uri = gedit_utils_str_middle_truncate (uri_for_display,
@@ -875,7 +875,7 @@ recent_tooltip_func_uim (EggRecentItem *item,
 	gchar *uri_for_display;
 	gchar *trunc_uri;
 
-	uri_for_display = egg_recent_item_get_uri_for_display (item);
+	uri_for_display = gedit_utils_format_uri_for_display (egg_recent_item_peek_uri (item));
 	g_return_val_if_fail (uri_for_display != NULL, NULL);
 
 	trunc_uri = gedit_utils_str_middle_truncate (uri_for_display,
@@ -1337,14 +1337,16 @@ static GeditWindow *
 clone_window (GeditWindow *origin)
 {
 	GtkWindow *window;
+	GdkScreen *screen;
 	GeditApp  *app;
 
 	gedit_debug (DEBUG_WINDOW);	
 
 	app = gedit_app_get_default ();
-	
-	window = GTK_WINDOW (gedit_app_create_window (app));
-	
+
+	screen = gtk_window_get_screen (GTK_WINDOW (origin));
+	window = GTK_WINDOW (gedit_app_create_window (app, screen));
+
 	gtk_window_set_default_size (window, 
 				     origin->priv->width,
 				     origin->priv->height);
